@@ -130,7 +130,7 @@ use Data::Serializer;
 
 # use Carp::Clan;
 use Carp;
-use Data::Dumper;
+#use Data::Dumper;
 # use Devel::Size qw(size total_size);
 # use Clone qw(clone);
 
@@ -138,7 +138,7 @@ use MIME::Base64;
 
 use vars qw( $VERSION );
 
-$VERSION = '2.06';
+$VERSION = '2.07';
 
 has 'active_size' => ( isa => 'ArrayRef', is => 'rw', required => 0 );
 has 'total_size'  => ( isa => 'ArrayRef', is => 'rw', required => 0 );
